var servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnSettings =
[
    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnSettings.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "Align", "servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnSettings.html#a7645c0b1b02b3ec44634fa3ab7e70bb1", null ],
    [ "ControlDefault", "servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnSettings.html#a67bb04a3f9a3ff0cd0c92a25f3f4c12e", null ],
    [ "ControlModel", "servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnSettings.html#a1faacb9b3134e41b40313cda5495b9dc", null ],
    [ "FormatKey", "servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnSettings.html#a44ff96471d7cdb5fbacf0932abaabee9", null ],
    [ "HelpText", "servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnSettings.html#a7e52ef40b5265c017585bf7d607ee31a", null ],
    [ "Hidden", "servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnSettings.html#a1922b1bc53179cdff4d220977a130e15", null ],
    [ "Position", "servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnSettings.html#a8a6513f134d7f992a895d24047427b9c", null ],
    [ "Width", "servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnSettings.html#a20c0d8eeeb1a2c61f0986a1c627c769a", null ]
];